PLUGIN = {}

PLUGIN.name = "leiningen"
PLUGIN.version = "0.1.0"
PLUGIN.homepage = "https://github.com/mise-plugins/vfox-leiningen"
PLUGIN.license = "MIT"
PLUGIN.description = "Leiningen - automating Clojure projects without setting your hair on fire"
PLUGIN.minRuntimeVersion = "0.3.0"
PLUGIN.notes = {
    "Requires Java to be installed",
}
